@@ -23,21 +23,21 @@
 
 QT_BEGIN_NAMESPACE
 
-#define USE_LAYOUT_SIZE_CONSTRAINT
+using namespace Qt::StringLiterals;
 
-static const char *leftMargin = "leftMargin";
-static const char *topMargin = "topMargin";
-static const char *rightMargin = "rightMargin";
-static const char *bottomMargin = "bottomMargin";
-static const char *horizontalSpacing = "horizontalSpacing";
-static const char *verticalSpacing = "verticalSpacing";
-static const char *spacing = "spacing";
-static const char *sizeConstraint = "sizeConstraint";
-static const char *boxStretchPropertyC = "stretch";
-static const char *gridRowStretchPropertyC = "rowStretch";
-static const char *gridColumnStretchPropertyC = "columnStretch";
-static const char *gridRowMinimumHeightPropertyC = "rowMinimumHeight";
-static const char *gridColumnMinimumWidthPropertyC = "columnMinimumWidth";
+static constexpr auto leftMargin = "leftMargin"_L1;
+static constexpr auto topMargin = "topMargin"_L1;
+static constexpr auto rightMargin = "rightMargin"_L1;
+static constexpr auto bottomMargin = "bottomMargin"_L1;
+static constexpr auto horizontalSpacing = "horizontalSpacing"_L1;
+static constexpr auto verticalSpacing = "verticalSpacing"_L1;
+static constexpr auto spacing = "spacing"_L1;
+static constexpr auto sizeConstraint = "sizeConstraint"_L1;
+static constexpr auto boxStretchPropertyC = "stretch"_L1;
+static constexpr auto gridRowStretchPropertyC = "rowStretch"_L1;
+static constexpr auto gridColumnStretchPropertyC = "columnStretch"_L1;
+static constexpr auto gridRowMinimumHeightPropertyC = "rowMinimumHeight"_L1;
+static constexpr auto gridColumnMinimumWidthPropertyC = "columnMinimumWidth"_L1;
 
 namespace {
     enum LayoutPropertyType {
@@ -67,7 +67,7 @@ namespace {
 static bool isIntegerList(const QString &s)
 {
     // Check for empty string or comma-separated list of integers
-    static const QRegularExpression re(QStringLiteral("^[0-9]+(,[0-9]+)+$"));
+    static const QRegularExpression re(u"^[0-9]+(,[0-9]+)+$"_s);
     Q_ASSERT(re.isValid());
     return s.isEmpty() || re.match(s).hasMatch();
 }
@@ -76,19 +76,19 @@ static bool isIntegerList(const QString &s)
 static LayoutPropertyType  layoutPropertyType(const QString &name)
 {
     static const QHash<QString, LayoutPropertyType> namePropertyMap = {
-        {QLatin1String(leftMargin), LayoutPropertyLeftMargin},
-        {QLatin1String(topMargin), LayoutPropertyTopMargin},
-        {QLatin1String(rightMargin), LayoutPropertyRightMargin},
-        {QLatin1String(bottomMargin), LayoutPropertyBottomMargin},
-        {QLatin1String(horizontalSpacing), LayoutPropertyHorizontalSpacing},
-        {QLatin1String(verticalSpacing), LayoutPropertyVerticalSpacing},
-        {QLatin1String(spacing), LayoutPropertySpacing},
-        {QLatin1String(sizeConstraint), LayoutPropertySizeConstraint},
-        {QLatin1String(boxStretchPropertyC ), LayoutPropertyBoxStretch},
-        {QLatin1String(gridRowStretchPropertyC), LayoutPropertyGridRowStretch},
-        {QLatin1String(gridColumnStretchPropertyC), LayoutPropertyGridColumnStretch},
-        {QLatin1String(gridRowMinimumHeightPropertyC), LayoutPropertyGridRowMinimumHeight},
-        {QLatin1String(gridColumnMinimumWidthPropertyC), LayoutPropertyGridColumnMinimumWidth}
+        {leftMargin, LayoutPropertyLeftMargin},
+        {topMargin, LayoutPropertyTopMargin},
+        {rightMargin, LayoutPropertyRightMargin},
+        {bottomMargin, LayoutPropertyBottomMargin},
+        {horizontalSpacing, LayoutPropertyHorizontalSpacing},
+        {verticalSpacing, LayoutPropertyVerticalSpacing},
+        {spacing, LayoutPropertySpacing},
+        {sizeConstraint, LayoutPropertySizeConstraint},
+        {boxStretchPropertyC, LayoutPropertyBoxStretch},
+        {gridRowStretchPropertyC, LayoutPropertyGridRowStretch},
+        {gridColumnStretchPropertyC, LayoutPropertyGridColumnStretch},
+        {gridRowMinimumHeightPropertyC, LayoutPropertyGridRowMinimumHeight},
+        {gridColumnMinimumWidthPropertyC, LayoutPropertyGridColumnMinimumWidth}
     };
     return namePropertyMap.value(name, LayoutPropertyNone);
 }
@@ -150,61 +150,59 @@ namespace qdesigner_internal {
 LayoutPropertySheet::LayoutPropertySheet(QLayout *l, QObject *parent)
     : QDesignerPropertySheet(l, parent), m_layout(l)
 {
-    const QString layoutGroup = QStringLiteral("Layout");
-    int pindex = createFakeProperty(QLatin1String(leftMargin), 0);
+    const QString layoutGroup = u"Layout"_s;
+    int pindex = createFakeProperty(leftMargin, 0);
     setPropertyGroup(pindex, layoutGroup);
 
-    pindex = createFakeProperty(QLatin1String(topMargin), 0);
+    pindex = createFakeProperty(topMargin, 0);
     setPropertyGroup(pindex, layoutGroup);
 
-    pindex = createFakeProperty(QLatin1String(rightMargin), 0);
+    pindex = createFakeProperty(rightMargin, 0);
     setPropertyGroup(pindex, layoutGroup);
 
-    pindex = createFakeProperty(QLatin1String(bottomMargin), 0);
+    pindex = createFakeProperty(bottomMargin, 0);
     setPropertyGroup(pindex, layoutGroup);
 
     const int visibleMask = LayoutProperties::visibleProperties(m_layout);
     if (visibleMask & LayoutProperties::HorizSpacingProperty) {
-        pindex = createFakeProperty(QLatin1String(horizontalSpacing), 0);
+        pindex = createFakeProperty(horizontalSpacing, 0);
         setPropertyGroup(pindex, layoutGroup);
 
-        pindex = createFakeProperty(QLatin1String(verticalSpacing), 0);
+        pindex = createFakeProperty(verticalSpacing, 0);
         setPropertyGroup(pindex, layoutGroup);
 
-        setAttribute(indexOf(QLatin1String(spacing)), true);
+        setAttribute(indexOf(spacing), true);
     }
 
     // Stretch
     if (visibleMask & LayoutProperties::BoxStretchProperty) {
-        pindex = createFakeProperty(QLatin1String(boxStretchPropertyC), QByteArray());
+        pindex = createFakeProperty(boxStretchPropertyC, QByteArray());
         setPropertyGroup(pindex, layoutGroup);
         setAttribute(pindex, true);
     } else {
         // Add the grid per-row/column stretch and size limits
         if (visibleMask & LayoutProperties::GridColumnStretchProperty) {
             const QByteArray empty;
-            pindex = createFakeProperty(QLatin1String(gridRowStretchPropertyC), empty);
+            pindex = createFakeProperty(gridRowStretchPropertyC, empty);
             setPropertyGroup(pindex, layoutGroup);
             setAttribute(pindex, true);
-            pindex = createFakeProperty(QLatin1String(gridColumnStretchPropertyC), empty);
+            pindex = createFakeProperty(gridColumnStretchPropertyC, empty);
             setPropertyGroup(pindex, layoutGroup);
             setAttribute(pindex, true);
-            pindex = createFakeProperty(QLatin1String(gridRowMinimumHeightPropertyC), empty);
+            pindex = createFakeProperty(gridRowMinimumHeightPropertyC, empty);
             setPropertyGroup(pindex, layoutGroup);
             setAttribute(pindex, true);
-            pindex = createFakeProperty(QLatin1String(gridColumnMinimumWidthPropertyC), empty);
+            pindex = createFakeProperty(gridColumnMinimumWidthPropertyC, empty);
             setPropertyGroup(pindex, layoutGroup);
             setAttribute(pindex, true);
         }
     }
-#ifdef USE_LAYOUT_SIZE_CONSTRAINT
     // SizeConstraint cannot possibly be handled as a real property
     // as it affects the layout parent widget and thus
     // conflicts with Designer's special layout widget.
     // It will take effect on the preview only.
-    pindex = createFakeProperty(QLatin1String(sizeConstraint));
+    pindex = createFakeProperty(sizeConstraint);
     setPropertyGroup(pindex, layoutGroup);
-#endif
 }
 
 LayoutPropertySheet::~LayoutPropertySheet() = default;
@@ -413,8 +411,8 @@ void LayoutPropertySheet::setChanged(int index, bool changed)
     switch (type) {
     case LayoutPropertySpacing:
         if (LayoutProperties::visibleProperties(m_layout) & LayoutProperties::HorizSpacingProperty) {
-            setChanged(indexOf(QLatin1String(horizontalSpacing)), changed);
-            setChanged(indexOf(QLatin1String(verticalSpacing)), changed);
+            setChanged(indexOf(horizontalSpacing), changed);
+            setChanged(indexOf(verticalSpacing), changed);
         }
         break;
     default:
@@ -435,31 +433,31 @@ void LayoutPropertySheet::stretchAttributesToDom(QDesignerFormEditorInterface *c
 
     // Stretch
     if (visibleMask & LayoutProperties::BoxStretchProperty) {
-        const int index = sheet->indexOf(QLatin1String(boxStretchPropertyC));
+        const int index = sheet->indexOf(boxStretchPropertyC);
         Q_ASSERT(index != -1);
         if (sheet->isChanged(index))
             domLayout->setAttributeStretch(sheet->property(index).toString());
     }
     if (visibleMask & LayoutProperties::GridColumnStretchProperty) {
-        const int index = sheet->indexOf(QLatin1String(gridColumnStretchPropertyC));
+        const int index = sheet->indexOf(gridColumnStretchPropertyC);
         Q_ASSERT(index != -1);
         if (sheet->isChanged(index))
             domLayout->setAttributeColumnStretch(sheet->property(index).toString());
     }
     if (visibleMask & LayoutProperties::GridRowStretchProperty) {
-        const int index = sheet->indexOf(QLatin1String(gridRowStretchPropertyC));
+        const int index = sheet->indexOf(gridRowStretchPropertyC);
         Q_ASSERT(index != -1);
         if (sheet->isChanged(index))
             domLayout->setAttributeRowStretch(sheet->property(index).toString());
     }
     if (visibleMask & LayoutProperties::GridRowMinimumHeightProperty) {
-        const int index = sheet->indexOf(QLatin1String(gridRowMinimumHeightPropertyC));
+        const int index = sheet->indexOf(gridRowMinimumHeightPropertyC);
         Q_ASSERT(index != -1);
         if (sheet->isChanged(index))
             domLayout->setAttributeRowMinimumHeight(sheet->property(index).toString());
     }
     if (visibleMask & LayoutProperties::GridColumnMinimumWidthProperty) {
-        const int index = sheet->indexOf(QLatin1String(gridColumnMinimumWidthPropertyC));
+        const int index = sheet->indexOf(gridColumnMinimumWidthPropertyC);
         Q_ASSERT(index != -1);
         if (sheet->isChanged(index))
             domLayout->setAttributeColumnMinimumWidth(sheet->property(index).toString());
@@ -473,15 +471,15 @@ void LayoutPropertySheet::markChangedStretchProperties(QDesignerFormEditorInterf
     QDesignerPropertySheetExtension *sheet = qt_extension<QDesignerPropertySheetExtension*>(core->extensionManager(), lt);
     Q_ASSERT(sheet);
     if (!domLayout->attributeStretch().isEmpty())
-        sheet->setChanged(sheet->indexOf(QLatin1String(boxStretchPropertyC)), true);
+        sheet->setChanged(sheet->indexOf(boxStretchPropertyC), true);
     if (!domLayout->attributeRowStretch().isEmpty())
-        sheet->setChanged(sheet->indexOf(QLatin1String(gridRowStretchPropertyC)), true);
+        sheet->setChanged(sheet->indexOf(gridRowStretchPropertyC), true);
     if (!domLayout->attributeColumnStretch().isEmpty())
-        sheet->setChanged(sheet->indexOf(QLatin1String(gridColumnStretchPropertyC)), true);
+        sheet->setChanged(sheet->indexOf(gridColumnStretchPropertyC), true);
    if (!domLayout->attributeColumnMinimumWidth().isEmpty())
-        sheet->setChanged(sheet->indexOf(QLatin1String(gridColumnMinimumWidthPropertyC)), true);
+        sheet->setChanged(sheet->indexOf(gridColumnMinimumWidthPropertyC), true);
    if (!domLayout->attributeRowMinimumHeight().isEmpty())
-        sheet->setChanged(sheet->indexOf(QLatin1String(gridRowMinimumHeightPropertyC)), true);
+        sheet->setChanged(sheet->indexOf(gridRowMinimumHeightPropertyC), true);
 }
 
 }
